Skip to contents

A protein abundance dataset exported from Scaffold, generated from Listeria lysate samples under four experimental conditions (6, ctrl, DM, and SIC). Each condition includes three technical replicates. The dataset is intended for illustrating the workflows implemented in msDiaLogue.

Usage

Scaffold_ListeriaLysates_Data

Format

A data frame with 1737 rows and 20 columns.