Skip to contents

A protein abundance dataset exported from Spectronaut, generated from a HeLa protein digest spiked with a six-protein digest mixture at three concentrations (50, 100, and 200 fmol). Each concentration includes four technical replicates. The dataset is intended for illustrating the workflows implemented in msDiaLogue.

Usage

Spectronaut_HeLa6Mix_Data

Format

A data frame with 672 rows and 16 columns.