Skip to contents

A small toy dataset exported from Scaffold. The data structure mimics the output format of Scaffold protein reports and can be used to demonstrate the workflow of the msDiaLogue package.

Usage

Toy_Scaffold_Data

Format

A data frame with 1737 rows and 20 columns.