Skip to contents

A small toy dataset exported from Spectronaut. The data structure mimics the output format of Spectronaut protein reports and can be used to demonstrate the workflow of the msDiaLogue package.

Usage

Toy_Spectronaut_Data

Format

A data frame with 672 rows and 16 columns.