Skip to contents

Apply imputation to the data set by the minimum measured value from any protein found within the entire data set.

Usage

impute.min_global(dataSet)

Arguments

dataSet

A data frame containing the data signals.

Value

An imputed data frame.