Scaffold Listeria lysates protein abundance dataset
Source:R/data.R
Scaffold_ListeriaLysates_Data.RdA protein abundance dataset exported from Scaffold, generated from Listeria lysate samples under four experimental conditions (6, ctrl, DM, and SIC). Each condition includes three technical replicates. The dataset is intended for illustrating the workflows implemented in msDiaLogue.