A small toy dataset exported from Scaffold. The data structure mimics the output format of Scaffold protein reports and can be used to demonstrate the workflow of the msDiaLogue package.
A small toy dataset exported from Scaffold. The data structure mimics the output format of Scaffold protein reports and can be used to demonstrate the workflow of the msDiaLogue package.