A small toy dataset exported from Spectronaut. The data structure mimics the output format of Spectronaut protein reports and can be used to demonstrate the workflow of the msDiaLogue package.
A small toy dataset exported from Spectronaut. The data structure mimics the output format of Spectronaut protein reports and can be used to demonstrate the workflow of the msDiaLogue package.