R/imputation.R
impute.min_global.Rd
Apply imputation to the data set by the minimum measured value from any protein found within the entire data set.
impute.min_global(dataSet)
A data frame containing the data signals.
An imputed data frame.