Generate a volcano plot for the data.
Arguments
- dataSet
The data set corresponds to the output from the function
analyze.mod_t,analyze.t, oranalyze.wilcox.- P.thres
A numeric value (default = 0.05) specifying the p-value threshold used to draw the horizontal line at -log10(
P.thres) on the volcano plot.- F.thres
threshold (default = 1) specifying the absolute fold change threshold used to draw the vertical lines at
-F.thresandF.threson the volcano plot.